summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--emailwiz.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/emailwiz.sh b/emailwiz.sh
index 924aaa1..64a64e4 100644
--- a/emailwiz.sh
+++ b/emailwiz.sh
@@ -93,10 +93,10 @@ postconf -e 'smtpd_sasl_auth_enable = yes'
postconf -e 'smtpd_sasl_type = dovecot'
postconf -e 'smtpd_sasl_path = private/auth'
# Sender and recipient restrictions
postconf -e "smtpd_sender_login_maps = pcre:/etc/postfix/login_maps.pcre"
-postconf -e "smtpd_sender_restrictions = permit_sasl_authenticated, permit_mynetworks, reject_sender_login_mismatch"
postconf -e 'smtpd_recipient_restrictions = permit_sasl_authenticated, permit_mynetworks, reject_unauth_destination, reject_unknown_recipient_domain'
+postconf -e 'smtpd_relay_restrictions = permit_sasl_authenticated, reject_unauth_destination'
# NOTE: the trailing slash here, or for any directory name in the home_mailbox
# command, is necessary as it distinguishes a maildir (which is the actual
@@ -93,10 +93,10 @@ postconf -e 'smtpd_sasl_auth_enable = yes'
postconf -e 'smtpd_sasl_type = dovecot'
postconf -e 'smtpd_sasl_path = private/auth'
-# Sender and recipient restrictions
+# Sender, relay and recipient restrictions
postconf -e "smtpd_sender_login_maps = pcre:/etc/postfix/login_maps.pcre"